==> haskell-criterion-1.1.4.0-18-i686.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.1.4.0
id: criterion-1.1.4.0-BRaaIZoaUKgGjxk9ibCKy1
key: criterion-1.1.4.0-BRaaIZoaUKgGjxk9ibCKy1
license: BSD3
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Measurement Criterion.Monad Criterion.Report
    Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
abi: 96662fedb03d105f4c287b76c9ace7e8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.1.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.1.4.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/criterion-1.1.4.0
hs-libraries: HScriterion-1.1.4.0-BRaaIZoaUKgGjxk9ibCKy1
depends:
    Glob-0.7.14-JPiVrtb5jL5BeQhtkal5dv
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx
    ansi-wl-pprint-0.6.7.3-BxXaXM4de7bF6SGXMvMtbC base-4.9.0.0
    binary-0.8.3.0 bytestring-0.10.8.1
    cassava-0.4.5.1-CXabyV2MEKy607ruPbuoTu
    code-page-0.1.2-JUSY2SsvUe26afmRK8ojg2 containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.2.6.2 filepath-1.4.1.0
    hastache-0.6.1-AnZxeJc4QP65v3cR8TBiTp
    js-flot-0.8.3-DwW7tRfA2DS2odTaEQO7re
    js-jquery-3.1.1-EFeKsBovKIlGfQQEZj8EWA
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.5.0-LMmPnBqFcyXKNTZwO31mEb
    optparse-applicative-0.13.1.0-IMOgMyEFJ9R7Y6gGL71zwn
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    statistics-0.13.3.0-H2z4HiHiqTE4HEQNobXAgb
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    vector-algorithms-0.7.0.1-7hkZdPzlc60Fe3nqzzgmcD
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.1.4.0-19-i686.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.1.4.0
id: criterion-1.1.4.0-4ICAUFOD3ixFzdm2TE3PK6
key: criterion-1.1.4.0-4ICAUFOD3ixFzdm2TE3PK6
license: BSD3
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Measurement Criterion.Monad Criterion.Report
    Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
abi: 996706c7e3f1c2fe7318a6a608ca9a87
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.1.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.1.4.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/criterion-1.1.4.0
hs-libraries: HScriterion-1.1.4.0-4ICAUFOD3ixFzdm2TE3PK6
depends:
    Glob-0.7.14-JPiVrtb5jL5BeQhtkal5dv
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx
    ansi-wl-pprint-0.6.7.3-BxXaXM4de7bF6SGXMvMtbC base-4.9.0.0
    binary-0.8.3.0 bytestring-0.10.8.1
    cassava-0.4.5.1-CXabyV2MEKy607ruPbuoTu
    code-page-0.1.2-JUSY2SsvUe26afmRK8ojg2 containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.2.6.2 filepath-1.4.1.0
    hastache-0.6.1-AnZxeJc4QP65v3cR8TBiTp
    js-flot-0.8.3-DwW7tRfA2DS2odTaEQO7re
    js-jquery-3.1.1-EFeKsBovKIlGfQQEZj8EWA
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.5.0-LMmPnBqFcyXKNTZwO31mEb
    optparse-applicative-0.13.2.0-403Af4vaGHEIyn0ZdeZhZL
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    statistics-0.13.3.0-H2z4HiHiqTE4HEQNobXAgb
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    vector-algorithms-0.7.0.1-7hkZdPzlc60Fe3nqzzgmcD
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
